@@ -33,9 +33,10 @@
 #  define LIBKEXIV2_DEPRECATED_NO_EXPORT LIBKEXIV2_NO_EXPORT LIBKEXIV2_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define LIBKEXIV2_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef LIBKEXIV2_NO_DEPRECATED
+#    define LIBKEXIV2_NO_DEPRECATED
+#  endif
 #endif
 
-#endif
+#endif /* LIBKEXIV2_EXPORT_H */
